@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/CodeLayout/RequireConsistentNewlines.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::Policy::CodeLayout::RequireConsistentNewlines;
 
 use 5.006001;
@@ -17,9 +10,9 @@ use PPI::Token::Whitespace;
 use English qw(-no_match_vars);
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.092';
+our $VERSION = '1.138';
 
-Readonly::Scalar my $LINE_END => qr/\015{1,2}\012|\012|\015/mxs;
+Readonly::Scalar my $LINE_END => qr/\015{1,2}\012|[\012\015]/mxs;
 
 #-----------------------------------------------------------------------------
 
@@ -57,7 +50,10 @@ sub violates {
         $newline ||= $nl;
         if ( $nl ne $newline ) {
             my $token = PPI::Token::Whitespace->new( $nl );
-            $token->{_location} = [$line, $col, $col];
+            # TODO this is a terrible violation of encapsulation, but absent a
+            # mechanism to override the line numbers in the violation, I do
+            # not know what to do about it.
+            $token->{_location} = [$line, $col, $col, $line, $filename];
             push @v, $self->violation( $DESC, $EXPL, $token );
         }
         $line++;
@@ -112,7 +108,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006 Chris Dolan.  All rights reserved.
+Copyright (c) 2006-2011 Chris Dolan.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
