@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/ControlStructures/ProhibitMutatingListFunctions.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::Policy::ControlStructures::ProhibitMutatingListFunctions;
 
 use 5.006001;
@@ -20,7 +13,7 @@ use Perl::Critic::Utils qw{
 
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.092';
+our $VERSION = '1.138';
 
 #-----------------------------------------------------------------------------
 
@@ -47,7 +40,7 @@ sub _is_topic {
     my $elem = shift;
     return defined $elem
         && $elem->isa('PPI::Token::Magic')
-            && $elem eq q{$_}; ##no critic (InterpolationOfMetachars)
+            && $elem->content() eq q{$_}; ##no critic (InterpolationOfMetachars)
 }
 
 
@@ -76,7 +69,7 @@ sub supported_parameters {
 }
 
 sub default_severity { return $SEVERITY_HIGHEST  }
-sub default_themes   { return qw(core bugs pbp)  }
+sub default_themes   { return qw(core bugs pbp certrule )  }
 sub applies_to       { return 'PPI::Token::Word' }
 
 #-----------------------------------------------------------------------------
@@ -103,7 +96,7 @@ sub violates {
     # Only the block form of list functions can be analyzed.
     return if not my $first_arg = first_arg( $elem );
     return if not $first_arg->isa('PPI::Structure::Block');
-    return if not _has_topic_side_effect( $first_arg );
+    return if not $self->_has_topic_side_effect( $first_arg, $doc );
 
     # Must be a violation
     return $self->violation( $DESC, $EXPL, $elem );
@@ -112,7 +105,7 @@ sub violates {
 #-----------------------------------------------------------------------------
 
 sub _has_topic_side_effect {
-    my $node = shift;
+    my ( $self, $node, $doc ) = @_;
 
     # Search through all significant elements in the block,
     # testing each element to see if it mutates the topic.
@@ -120,7 +113,7 @@ sub _has_topic_side_effect {
     for my $elem ( @{ $tokens } ) {
         next if not $elem->significant();
         return 1 if _is_assignment_to_topic( $elem );
-        return 1 if _is_topic_mutating_regex( $elem );
+        return 1 if $self->_is_topic_mutating_regex( $elem, $doc );
         return 1 if _is_topic_mutating_func( $elem );
         return 1 if _is_topic_mutating_substr( $elem );
     }
@@ -149,10 +142,42 @@ sub _is_assignment_to_topic {
 #-----------------------------------------------------------------------------
 
 sub _is_topic_mutating_regex {
-    my $elem = shift;
+    my ( $self, $elem, $doc ) = @_;
     return if ! ( $elem->isa('PPI::Token::Regexp::Substitute')
                   || $elem->isa('PPI::Token::Regexp::Transliterate') );
 
+    # Exempt PPI::Token::Regexp::Transliterate objects IF the replacement
+    # string is empty AND neither the /d or /s flags are specified, OR the
+    # replacement string equals the match string AND neither the /c or /s
+    # flags are specified. RT 44515.
+    #
+    # NOTE that, at least as of 5.14.2, tr/// does _not_ participate in the
+    # 'use re /modifiers' mechanism. And a good thing, too, since the
+    # modifiers that _are_ common (/s and /d) mean something completely
+    # different in tr///.
+    if ( $elem->isa( 'PPI::Token::Regexp::Transliterate') ) {
+        my $subs = $elem->get_substitute_string();
+        my %mods = $elem->get_modifiers();
+        $mods{r} and return;    # Introduced in Perl 5.13.7
+        if ( $EMPTY eq $subs ) {
+            $mods{d} or $mods{s} or return;
+        } elsif ( $elem->get_match_string() eq $subs ) {
+            $mods{c} or $mods{s} or return;
+        }
+    }
+
+    # As of 5.13.2, the substitute built-in supports the /r modifier, which
+    # causes the operation to return the modified string and leave the
+    # original unmodified. This does not parse under earlier Perls, so there
+    # is no version check.
+
+    if ( $elem->isa( 'PPI::Token::Regexp::Substitute' ) ) {
+        my $re = $doc->ppix_regexp_from_element( $elem )
+            or return;
+        $re->modifier_asserted( 'r' )
+            and return;
+    }
+
     # If the previous sibling does not exist, then
     # the regex implicitly binds to $_
     my $prevsib = $elem->sprevious_sibling;
@@ -174,7 +199,7 @@ sub _is_topic_mutating_func {
     my $elem = shift;
     return if not $elem->isa('PPI::Token::Word');
     my @mutator_funcs = qw(chop chomp undef);
-    return if not any { $elem eq $_ } @mutator_funcs;
+    return if not any { $elem->content() eq $_ } @mutator_funcs;
     return if not is_function_call( $elem );
 
     # If these functions have no argument,
@@ -182,7 +207,7 @@ sub _is_topic_mutating_func {
     my $first_arg = first_arg( $elem );
     if (not defined $first_arg) {
         # undef does not default to $_, unlike the others
-        return if $elem eq 'undef';
+        return if $elem->content() eq 'undef';
         return 1;
     }
     return _is_topic( $first_arg );
@@ -194,7 +219,7 @@ Readonly::Scalar my $MUTATING_SUBSTR_ARG_COUNT => 4;
 
 sub _is_topic_mutating_substr {
     my $elem = shift;
-    return if $elem ne 'substr';
+    return if $elem->content() ne 'substr';
     return if not is_function_call( $elem );
 
     # check and see if the first arg is $_
@@ -207,7 +232,9 @@ sub _is_topic_mutating_substr {
 {
     ##no critic(ArgUnpacking)
 
-    my %assignment_ops = hashify qw( = *= /= += -= %= **= x= .= &= |= ^=  &&= ||= ++ -- );
+    my %assignment_ops = hashify qw(
+        = *= /= += -= %= **= x= .= &= |= ^=  &&= ||= <<= >>= //= ++ --
+    );
     sub _is_assignment_operator { return exists $assignment_ops{$_[0]} }
 
     my %increment_ops = hashify qw( ++ -- );
@@ -229,6 +256,7 @@ __END__
 
 Perl::Critic::Policy::ControlStructures::ProhibitMutatingListFunctions - Don't modify C<$_> in list functions.
 
+
 =head1 AFFILIATION
 
 This Policy is part of the core L<Perl::Critic|Perl::Critic>
@@ -287,15 +315,23 @@ This policy looks only for modifications of C<$_>.  Other naughtiness
 could include modifying C<$a> and C<$b> in C<sort> and the like.
 That's beyond the scope of this policy.
 
+
+=head1 SEE ALSO
+
+There is discussion of this policy at
+L<http://perlmonks.org/index.pl?node_id=743445>.
+
+
 =head1 AUTHOR
 
 Chris Dolan <cdolan@cpan.org>
 
 Michael Wolf <MichaelRWolf@att.net>
 
+
 =head1 COPYRIGHT
 
-Copyright (C) 2006 Chris Dolan.  All rights reserved.
+Copyright (c) 2006-2011 Chris Dolan.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
