@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/InputOutput/ProhibitTwoArgOpen.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::Policy::InputOutput::ProhibitTwoArgOpen;
 
 use 5.006001;
@@ -18,11 +11,12 @@ use version;
 use Perl::Critic::Utils qw{ :severities :classification :ppi };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.092';
+our $VERSION = '1.138';
 
 #-----------------------------------------------------------------------------
 
 Readonly::Scalar my $STDIO_HANDLES_RX => qr/\b STD (?: IN | OUT | ERR \b)/xms;
+Readonly::Scalar my $FORK_HANDLES_RX => qr/\A (?: -[|] | [|]- ) \z/xms;
 Readonly::Scalar my $DESC => q{Two-argument "open" used};
 Readonly::Scalar my $EXPL => [ 207 ];
 
@@ -32,7 +26,7 @@ Readonly::Scalar my $MINIMUM_VERSION => version->new(5.006);
 
 sub supported_parameters { return ()                         }
 sub default_severity     { return $SEVERITY_HIGHEST          }
-sub default_themes       { return qw(core pbp bugs security) }
+sub default_themes       { return qw(core pbp bugs security certrule) }
 sub applies_to           { return 'PPI::Token::Word'         }
 
 #-----------------------------------------------------------------------------
@@ -40,7 +34,7 @@ sub applies_to           { return 'PPI::Token::Word'         }
 sub violates {
     my ($self, $elem, $document) = @_;
 
-    return if $elem ne 'open';
+    return if $elem->content() ne 'open';
     return if ! is_function_call($elem);
 
     my $version = $document->highest_explicit_perl_version();
@@ -52,6 +46,8 @@ sub violates {
         # When opening STDIN, STDOUT, or STDERR, the
         # two-arg form is the only option you have.
         return if $args[1]->[0] =~ $STDIO_HANDLES_RX;
+        return if $args[1]->[0]->isa( 'PPI::Token::Quote' )
+               && $args[1]->[0]->string() =~ $FORK_HANDLES_RX;
         return $self->violation( $DESC, $EXPL, $elem );
     }
 
@@ -66,6 +62,8 @@ __END__
 
 =pod
 
+=for stopwords perlipc
+
 =head1 NAME
 
 Perl::Critic::Policy::InputOutput::ProhibitTwoArgOpen - Write C<< open $fh, q{<}, $filename; >> instead of C<< open $fh, "<$filename"; >>.
@@ -108,9 +106,9 @@ This Policy is not configurable except for the standard options.
 
 =head1 NOTES
 
-The only time you should use the two-argument form is when you re-open
-STDIN, STDOUT, or STDERR.  But for now, this Policy doesn't provide
-that loophole.
+There are two cases in which you are forced to use the two-argument form of
+open. When re-opening STDIN, STDOUT, or STDERR, and when doing a safe pipe
+open, as described in L<perlipc|perlipc>.
 
 =head1 SEE ALSO
 
@@ -120,11 +118,11 @@ L<IO::File|IO::File>
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2007 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
