@@ -1,9 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/Modules/ProhibitEvilModules.pm $
-#     $Date: 2010-06-22 16:14:07 -0400 (Tue, 22 Jun 2010) $
-#   $Author: clonezone $
-# $Revision: 3843 $
-##############################################################################
 package Perl::Critic::Policy::Modules::ProhibitEvilModules;
 
 use 5.006001;
@@ -21,7 +15,7 @@ use Perl::Critic::Utils qw{
 
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.108';
+our $VERSION = '1.138';
 
 #-----------------------------------------------------------------------------
 
@@ -100,7 +94,7 @@ sub supported_parameters {
 }
 
 sub default_severity  { return $SEVERITY_HIGHEST         }
-sub default_themes    { return qw( core bugs )           }
+sub default_themes    { return qw( core bugs certrule )           }
 sub applies_to        { return 'PPI::Statement::Include' }
 
 #-----------------------------------------------------------------------------
@@ -359,7 +353,7 @@ Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2010 Imaginative Software Systems.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
