@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/Subroutines/ProhibitSubroutinePrototypes.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::Policy::Subroutines::ProhibitSubroutinePrototypes;
 
 use 5.006001;
@@ -15,7 +8,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.092';
+our $VERSION = '1.138';
 
 #-----------------------------------------------------------------------------
 
@@ -26,7 +19,7 @@ Readonly::Scalar my $EXPL => [ 194 ];
 
 sub supported_parameters { return ()                    }
 sub default_severity     { return $SEVERITY_HIGHEST     }
-sub default_themes       { return qw(core pbp bugs)     }
+sub default_themes       { return qw(core pbp bugs certrec )     }
 sub applies_to           { return 'PPI::Statement::Sub' }
 
 #-----------------------------------------------------------------------------
@@ -70,11 +63,11 @@ This Policy is not configurable except for the standard options.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
