@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/Policy/Variables/ProtectPrivateVars.pm $
-#     $Date: 2010-06-22 16:14:07 -0400 (Tue, 22 Jun 2010) $
-#   $Author: clonezone $
-# $Revision: 3843 $
-##############################################################################
-
 package Perl::Critic::Policy::Variables::ProtectPrivateVars;
 
 use 5.006001;
@@ -15,7 +8,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.108';
+our $VERSION = '1.138';
 
 #-----------------------------------------------------------------------------
 
@@ -26,7 +19,7 @@ Readonly::Scalar my $EXPL => q{Use published APIs};
 
 sub supported_parameters { return ()                   }
 sub default_severity     { return $SEVERITY_MEDIUM     }
-sub default_themes       { return qw(core maintenance) }
+sub default_themes       { return qw(core maintenance certrule ) }
 sub applies_to           { return 'PPI::Token::Symbol' }
 
 #-----------------------------------------------------------------------------
@@ -89,7 +82,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Chris Dolan.
+Copyright (c) 2006-2011 Chris Dolan.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
